@@ -91,10 +91,12 @@ class Bitwarden(object):
             )
             self.bitwarden_token = bitwarden_app.stdout
             if "Invalid master password" in self.bitwarden_token:
-                logging.error(bitwarden_app.stdout)
+                logging.error("STDOUT: " + bitwarden_app.stdout)
+                logging.error("STDERR: " + bitwarden_app.stderr)
                 raise Exception("Invalid master password!")
         else:
-            logging.error(bitwarden_app.stdout)
+            logging.error("STDOUT: " + bitwarden_app.stdout)
+            logging.error("STDERR: " + bitwarden_app.stderr)
             raise Exception("Failed to login via api key!")
 
     def get_credentials(self, user_credentials_name):
@@ -164,6 +166,10 @@ class Bitwarden(object):
                         for field in bw_item["fields"]:
                             self.data[credentials_key][field["name"]] = field["value"]
         if len(self.data) != len(data):
-            logging.error("Can't get data from bitwarden")
-            raise Exception("Bitwarden ERROR")
+            logging.error(
+                "Can't get data from bitwarden. Probably invalid collection or key name!"
+            )
+            raise Exception(
+                "Can't get data from bitwarden. Probably invalid collection or key name!"
+            )
         self.bitwarden_exe("logout")
